@@ -29,3 +29,15 @@ test_that("useful message if objects equal but not identical", {
   expect_failure(expect_identical(f, g), "not identical")
 })
 
+test_that("% is not treated as sprintf format specifier (#445)", {
+  expect_failure(expect_equal("+", "%"))
+  expect_failure(expect_equal("%", "+"))
+  expect_equal("%", "%")
+})
+
+test_that("attributes for object (#452)", {
+  oops <- structure(0, oops = "oops")
+  expect_equal(oops, oops)
+  expect_failure(expect_equal(oops, 0))
+  expect_equal(as.numeric(oops), 0)
+})
